@@ -14,5 +14,5 @@ DIR="$( cd "$( dirname "$0" )" && pwd )"
 if [ $5 -eq 1 ]; then
   ruby -rubygems $DIR/logolIndex.rb --search $3.index --min $2 --max $6 --pattern $4 --error $1 --hamming
 else
-  ruby -rubygems $DIR/logolIndex.rb --search $3.index --min $2 --max $6 --pattern $4 -error $1
-fi
\ No newline at end of file
+  ruby -rubygems $DIR/logolIndex.rb --search $3.index --min $2 --max $6 --pattern $4 --error $1
+fi
